==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/outputs/ProtectedItemModelPropertiesResponseLastTestFailoverJob.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property displayName Gets or sets the workflow friendly display name.
 * @property endTime Gets or sets end time of the workflow.
 * @property id Gets or sets workflow Id.
 * @property name Gets or sets workflow name.
 * @property scenarioName Gets or sets protection scenario name.
 * @property startTime Gets or sets start time of the workflow.
 * @property state Gets or sets workflow state.
 */
public data class ProtectedItemModelPropertiesResponseLastTestFailoverJob(
    public val displayName: String,
    public val endTime: String,
    public val id: String,
    public val name: String,
    public val scenarioName: String,
    public val startTime: String,
    public val state: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datareplication.outputs.ProtectedItemModelPropertiesResponseLastTestFailoverJob):
            ProtectedItemModelPropertiesResponseLastTestFailoverJob =
            ProtectedItemModelPropertiesResponseLastTestFailoverJob(
                displayName = javaType.displayName(),
                endTime = javaType.endTime(),
                id = javaType.id(),
                name = javaType.name(),
                scenarioName = javaType.scenarioName(),
                startTime = javaType.startTime(),
                state = javaType.state(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/outputs/ProtectedItemModelPropertiesResponseLastTestFailoverJob.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property displayName Gets or sets the workflow friendly display name.
 * @property endTime Gets or sets end time of the workflow.
 * @property id Gets or sets workflow Id.
 * @property name Gets or sets workflow name.
 * @property scenarioName Gets or sets protection scenario name.
 * @property startTime Gets or sets start time of the workflow.
 * @property state Gets or sets workflow state.
 */
public data class ProtectedItemModelPropertiesResponseLastTestFailoverJob(
    public val displayName: String,
    public val endTime: String,
    public val id: String,
    public val name: String,
    public val scenarioName: String,
    public val startTime: String,
    public val state: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datareplication.outputs.ProtectedItemModelPropertiesResponseLastTestFailoverJob): ProtectedItemModelPropertiesResponseLastTestFailoverJob =
            ProtectedItemModelPropertiesResponseLastTestFailoverJob(
                displayName = javaType.displayName(),
                endTime = javaType.endTime(),
                id = javaType.id(),
                name = javaType.name(),
                scenarioName = javaType.scenarioName(),
                startTime = javaType.startTime(),
                state = javaType.state(),
            )
    }
}
